netapp_ontap.models.kerberos_realm_ad_server API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.kerberos_realm_ad_server`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class KerberosRealmAdServerSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the KerberosRealmAdServer object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `address GET POST PATCH`

    Active Directory server IP address

    Example: 1.2.3.4

  `name GET POST PATCH`

    Active Directory server name